@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V1.2.1-0
+# Application Name - Health Check V1.2.1-1
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -93,36 +93,36 @@ class camerasClass(QtGui.QMainWindow):
 		self.pushButton_cam.setObjectName("pushButton_cam")
 		self.pushButton_cam.setText("Front camera")
 		# Tell the button what to do when it is clicked.
-		QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.updateTab3)
+		QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.funcFrontCamTest)
 		# Setup and draw the button
 		self.pushButton_cam2 = QtGui.QPushButton(self)
 		self.pushButton_cam2.setGeometry(QtCore.QRect(300, 380, 331, 71))
 		self.pushButton_cam2.setObjectName("pushButton_cam2")
 		self.pushButton_cam2.setText("Back camera")
 		# Tell the button what to do when it is clicked.
-		QtCore.QObject.connect(self.pushButton_cam2, QtCore.SIGNAL('clicked()'), self.updateTab3a)
+		QtCore.QObject.connect(self.pushButton_cam2, QtCore.SIGNAL('clicked()'), self.funcBackCamTest)
 		self.exitb = QtGui.QPushButton('X', self)
 		self.exitb.setGeometry(QtCore.QRect(600, 380, 101, 71))
 		self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.close)
 		
-	def updateTab3(self):
+	def funcFrontCamTest(self):
 		print " ** Starting update3**"
 		self.pushButton_cam.setEnabled(False)
 		self.pushButton_cam.setText("....")
-		self.updateImage()
+		self.funcFrontCamCapture()
 		self.pushButton_cam.setText("Front camera")
 		self.pushButton_cam.setEnabled(True)
 
-	def updateTab3a(self):
+	def funcBackCamTest(self):
 		print " ** Starting update3a**"
 		self.pushButton_cam2.setEnabled(False)
 		self.pushButton_cam2.setText("....")
-		self.updateImage2()
+		self.funcBackCamCapture()
 		self.pushButton_cam2.setText("Back Camera")
 		self.pushButton_cam2.setEnabled(True)
 
 	# Funtion - update the front camera image
-	def updateImage(self):
+	def funcFrontCamCapture(self):
 		print "** Starting front camera function **"
 		bus = dbus.SessionBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
@@ -137,7 +137,7 @@ class camerasClass(QtGui.QMainWindow):
 		self.lblCameraImage.setPixmap(image)
 		print " ** Finished front camera function **"
 
-	def updateImage2(self):
+	def funcBackCamCapture(self):
 		print " ** Starting back camera function **"
 		bus = dbus.SessionBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
@@ -323,7 +323,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		# Draw the Menubar
 		fremantle = MainWindow.menuBar().addMenu("Update");
 		act = fremantle.addAction("Update All")
-		QtCore.QObject.connect(act, QtCore.SIGNAL("triggered()"), self.updateAll)
+		QtCore.QObject.connect(act, QtCore.SIGNAL("triggered()"), self.funcUpdateAll)
 		#actb = fremantle.addAction("System")
 		#QtCore.QObject.connect(actb, QtCore.SIGNAL("triggered()"), self.updateTab1)
 		#actc = fremantle.addAction("Comms")
@@ -449,13 +449,13 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		self.pushButton_led.setGeometry(QtCore.QRect(10, 70, 391, 51))
 		self.pushButton_led.setObjectName("pushButton_led")
 		self.pushButton_led.setText("Test LEDs")
-		QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.updateLED)
+		QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.funcLEDTest)
 
 		self.pushButton_von = QtGui.QPushButton(self.tab_3)
 		self.pushButton_von.setGeometry(QtCore.QRect(10, 130, 391, 51))
 		self.pushButton_von.setObjectName("pushButton_von")
 		self.pushButton_von.setText("Test Vibrate")
-		QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
+		QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.funcVibrateTest)
 
 		self.xyscreen = QtGui.QPushButton(self.tab_3)
 		self.xyscreen.setGeometry(QtCore.QRect(10, 190, 391, 51))
@@ -467,7 +467,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		self.pushButton_cama.setGeometry(QtCore.QRect(10, 250, 391, 51))
 		self.pushButton_cama.setObjectName("pushButton_cama")
 		self.pushButton_cama.setText("Camera Tests")
-		QtCore.QObject.connect(self.pushButton_cama, QtCore.SIGNAL('clicked()'), self.updateimage)
+		QtCore.QObject.connect(self.pushButton_cama, QtCore.SIGNAL('clicked()'), self.funcFrontCamCapture)
 		
 		self.pushButton_reboot = QtGui.QPushButton(self.tab_3)
 		self.pushButton_reboot.setGeometry(QtCore.QRect(10, 310, 391, 51))
@@ -637,7 +637,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		aui.show()
 		aui.showFullScreen()
 		
-	def updateimage(self):  
+	def funcFrontCamCapture(self):  
 		imagewin.show()
 		imagewin.showFullScreen()
 		                                	
@@ -671,7 +671,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		b = os.popen(bb)
 		b.close ()
  
-	def updatenetname(self):
+	def funcCommsInfo(self):
 		g = gn_functions.funcHostName()
 		self.listWidget2.addItem("Device Hostname \t" + g.strip())
 
@@ -700,7 +700,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
                 self.listWidget2.addItem("Bluetooth MAC \t" + g.strip())
 
 
-	def vibrateon(self):
+	def funcVibrateTest(self):
                 
 		print " ** testing vibrations**"
 		bus = dbus.SessionBus()
@@ -720,7 +720,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		b.close()
 		print " ** finished vibrations**"
 		
-	def updateLED(self):
+	def funcLEDTest(self):
 		print " ** Starting LED Patterns**"
 		bus = dbus.SessionBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
@@ -745,7 +745,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
 		interface.Notify('HealthCheck', 0, 'general_refresh', 'LED TEST', 'Completed LED Test', [], {}, 3000)
 
-	def updaterootfs(self):
+	def funcSystemTab(self):
 		g = gn_functions.funcRootUsed()
 		self.listWidget.addItem("Rootfs % Used \t\t" + g.strip())
 
@@ -843,10 +843,14 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		self.listWidget.addItem("Accelerometer \t\t" + g)
 
                 g = gn_functions.funcDevOri()
-                self.listWidget.addItem("Device Orientation \t\t" + g)  
+                self.listWidget.addItem("Device Orientation \t\t" + g)
+
+                g = gn_functions.funcCPUMinMax()
+                self.listWidget.addItem("CPU Min / Max Frequencies \t" + g)
+                
 		
 
-	def updateAll(self):
+	def funcUpdateAll(self):
 		print " ** Running Update ALL**"
 		progress = QtGui.QProgressDialog("Please Wait", "Cancel", 0, 100, MainWindow)
 		progress.setWindowModality(QtCore.Qt.WindowModal)
@@ -868,7 +872,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
                 progress.setValue(33)
                 progress.setWindowTitle("Loading Healthcheck - System Tab")
                 QtGui.QApplication.processEvents()
-                self.updaterootfs()
+                self.funcSystemTab()
                 time.sleep(0.1)
                 progress.setValue(45)
                 QtGui.QApplication.processEvents()
@@ -888,7 +892,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		QtGui.QApplication.processEvents()
                 time.sleep(0.1)
                 progress.setValue(90)
-		self.updatenetname()
+		self.funcCommsInfo()
 		QtGui.QApplication.processEvents()
 		progress.setWindowTitle("Loading Healthcheck - Networks")
 		progress.setValue(95)
@@ -962,12 +966,12 @@ class Ui_MainWindow(QtGui.QMainWindow):
 	def updateGPS(self, MainWindow):
 		print "** Updating GPS Info**"
 		global var_g_GPS
-		global var_g_ALT
 		# Start of the GPS Location information
 		# Please visit here for more information and code on PyMaemo GPS API - http://wiki.maemo.org/PyMaemo/Using_Location_API
 		loop = gobject.MainLoop()
 		control = location.GPSDControl.get_default()
 		device = location.GPSDevice()
+                #control.set_properties(preferred_method=location.METHOD_GNSS|location.METHOD_AGNSS,preferred_interval=location.INTERVAL_DEFAULT)
 		control.set_properties(preferred_method=location.METHOD_USER_SELECTED,preferred_interval=location.INTERVAL_DEFAULT)
 		control.connect("error-verbose", on_error, loop)
 		device.connect("changed", on_changed, control)
@@ -989,28 +993,29 @@ def on_error(control, error, user_data):
 	elif error == location.ERROR_SYSTEM:
 		print "System error"
 	control.stop()
-        data.quit()
+	user_data.quit()
+        #data.quit()
 		
 # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, partially commented by me
 # Moved out of the class by me
 def on_changed(device, data):
 	print " ** GPS On Changed function"
 	global var_g_GPS
-	global var_g_ALT
 	if not device:
 		var_g_GPS = "No GPS Found"
-		var_g_ALT = ""
 		return
-	if device.fix:
-		if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
-			#Set our global variable as the location information! - scroll backup to see where it was used
-			var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
-			#Seems to struggle with doing it once.... so do it 5 times to warm it up!
-		for i in range(1, 5):
-			if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
-				var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
-			data.stop()
-			print " ** Stopped GPS Fix **"
+        for i in range(1, 10):
+                if device.fix:
+                        if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
+                                #Set our global variable as the location information! - scroll backup to see where it was used
+                                var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
+                                #Seems to struggle with doing it once.... so do it 5 times to warm it up!
+                        
+                                if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
+                                        var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
+                                print var_g_GPS
+	data.stop()
+	print " ** Stopped GPS Fix **"
 
 # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, uncommented by me
 # Moved out of the class by me
@@ -1053,7 +1058,7 @@ if __name__ == "__main__":
 	print " ** Show everything**"
 	MainWindow.show()
 	print " ** Waiting for quit signal - healthcheck loaded **"
-	ui.updateAll()
+	ui.funcUpdateAll()
 	sys.exit(app.exec_())
 	print " ** sys.exit called**"
 
